/*
 *  
 *  $Id: iconos.h 4625 2012-01-30 09:27:26Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once

#include "ico_abrir.h"
#include "ico_cerrar_tab.h"
#include "ico_configuracion.h"
#include "ico_editor.h"
#include "ico_exportar.h"
#include "ico_filtrado.h"
#include "ico_guardar.h"
#include "ico_importar.h"
#include "ico_reset.h"
#include "ico_salir.h"
#include "ico_impresora.h"
#include "ico_vista_preliminar.h"
#include "ico_calibrar_imagen.h"
#include "ico_editar.h"
#include "ico_eliminar_widget.h"
#include "ico_eliminar_todo.h"
#include "ico_pantalla_completa.h"
#include "ico_open_dir.h"
#include "ico_open_file.h"
#include "ico_user.h"
#include "ico_help.h"
#include "ico_support.h"
#include "ico_acercade.h"
#include "ico_send_to_pacs.h"
#include "ico_obtain_extensions.h"
#include "ico_dicom_dir.h"
#include "ico_open_disc.h"
#include "ico_tick.h"
#include "ico_cross.h"
